
.. _`CIM data types`:

CIM data types
--------------

.. automodule:: pywbem.cim_types

.. autoclass:: pywbem.CIMType
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMType
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMType
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.CIMDateTime
   :members:
   :exclude-members: __hash__

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMDateTime
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMDateTime
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.MinutesFromUTC
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.MinutesFromUTC
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.MinutesFromUTC
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.CIMInt
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMInt
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMInt
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.Uint8
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.Uint8
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.Uint8
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.Sint8
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.Sint8
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.Sint8
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.Uint16
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.Uint16
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.Uint16
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.Sint16
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.Sint16
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.Sint16
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.Uint32
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.Uint32
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.Uint32
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.Sint32
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.Sint32
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.Sint32
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.Uint64
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.Uint64
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.Uint64
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.Sint64
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.Sint64
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.Sint64
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.CIMFloat
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMFloat
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMFloat
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.Real32
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.Real32
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.Real32
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.Real64
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.Real64
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.Real64
      :attributes:

   .. rubric:: Details
